CityCoordinates class abstract

A geocoded location: latitude/longitude plus the resolved place names returned by Nominatim.

Available extensions
Annotations
  • @freezed

Constructors

CityCoordinates({required double latitude, required double longitude, required String displayName, String? city, String? country})
const
factory

Properties

city String?
no setterinherited
copyWith → $CityCoordinatesCopyWith<CityCoordinates>
Create a copy of CityCoordinates with the given fields replaced by the non-null parameter values.
no setterinherited
country String?
no setterinherited
displayName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
latitude double
no setterinherited
longitude double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_CityCoordinates value)) → TResult

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_CityCoordinates value)?) → TResult?

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_CityCoordinates value)?, {required TResult orElse()}) → TResult

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(double latitude, double longitude, String displayName, String? city, String? country)?, {required TResult orElse()}) → TResult

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(double latitude, double longitude, String displayName, String? city, String? country)) → TResult

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(double latitude, double longitude, String displayName, String? city, String? country)?) → TResult?

Available on CityCoordinates, provided by the CityCoordinatesPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited